Binary Plots
============

.. toctree::

   reference_xyy_to_profile
   reference_binary_axes_subplot_poisson
   reference_binary_figure
   reference_binary_plot_convergence
   reference_binary_plot_n_equilibria
   reference_binary_plot_winners_at_equilibrium
   reference_binary_plot_winning_frequencies
